##
##  lz4.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         lz4
Summary:      High-Performance Compression Library
URL:          http://www.lz4.org
Vendor:       Yann Collet
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Compression
License:      BSD
Version:      1.10.0
Release:      20240728

#   list of sources
Source0:      https://github.com/lz4/lz4/archive/v%{version}.tar.gz
Patch0:       lz4.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, gcc, make
PreReq:       OpenPKG, openpkg >= 20160101

%description
    LZ4 is a very fast lossless compression algorithm, providing
    compression speed at 400 MB/s per core, with near-linear scalability
    for multi-threaded applications. It also features an extremely fast
    decoder, with speed in multiple GB/s per core, typically reaching
    RAM speed limits on multi-core systems. LZ4 is used in the popular
    ZFS filesystem.

%track
    prog lz4 = {
        version   = %{version}
        url       = https://github.com/lz4/lz4/releases
        regex     = tree/v(\d+\.\d+\.\d+)
    }

%prep
    %setup -q -n lz4-%{version}
    %patch -p0

%build
    %{l_make} %{l_mflags} \
        CC="%{l_cc}" \
        CFLAGS="%{l_cflags -O}" \
        BUILD_SHARED=no \
        BUILD_STATIC=yes \
        V=1

%install
    %{l_make} %{l_mflags} install \
        DESTDIR=$RPM_BUILD_ROOT \
        PREFIX=%{l_prefix} \
        BUILD_SHARED=no \
        BUILD_STATIC=yes
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

